==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/lv.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "%s personīgā darbību plūsma ",
    "Your feed URL is invalid" : "Jūsu plūsmas URL nav derīgs.",
    "Activity feed for %1$s" : "%1$s darbību plūsma",
    "Activity feed" : "Darbību plūsma",
    "Your settings have been updated." : "Jūsu uzstādījumi ir atjaunoti.",
    "Settings have been updated." : "Iestādījumi ir atjaunoti.",
    "Recent activity" : "Jaunākās darbības",
    "No activities" : "Nav darbību",
    "More activities" : "Vairāk darbību",
    "_and %n more…_::_and %n more…_" : ["un vēl %n...","un vēl %n...","un vēl %n..."],
    "All activities" : "Visas darbības",
    "By others" : "Citu",
    "By you" : "Jūsu",
    "Activity at %s" : "Darbības %s",
    "Hello %s" : "Sveiki, %s",
    "Hello %s," : "Sveiki, %s,",
    "There was some activity at %s" : "%s bija kaut kādas darbības",
    "_and %n more _::_and %n more _" : ["un vēl %n","un vēl %n","un vēl %n"],
    "Mail" : "E-pasts",
    "Activity" : "Darbības",
    "Notifications" : "Paziņojumi",
    "Send email" : "Sūtīt e-pastu",
    "Activity notification configuration" : "Darbību paziņojumu konfigurācija",
    "Today" : "Šodien",
    "Yesterday" : "Vakar",
    "You need to set up your email address before you can receive notification emails." : "Lai saņemtu paziņojumus e-pastā, jūsu profilā ir nepieciešams uzstādīt e-pasta adresi.",
    "Send activity emails" : "Sūtīt darbību e-pastus",
    "As soon as possible" : "Pēc iespējas atrāk",
    "Hourly" : "Ik stundu",
    "Daily" : "Katru dienu",
    "Weekly" : "Katru nedēļu",
    "You commented" : "Tu piebildi",
    "Message deleted by author" : "Ziņojumu izdzēsa autors",
    "Open {filename}" : "Atvērt {filename}",
    "in {path}" : "{path}",
    "Home" : "Sākums",
    "Could not load activities" : "Nevarēja ielādēt darbības",
    "Loading activities" : "Ielādē darbības",
    "This stream will show events like additions, changes & shares" : "Šajā plūsmā tiks parādīti papildinājumu, izmaiņu un koplietošanas notikumi",
    "No activity yet" : "Vēl nav darbības",
    "Loading more activities" : "Ielādē vairāk darbību",
    "No more activities." : "Nav vairāk darbību.",
    "Could not enable RSS link" : "Nevarēja iespējot RSS saiti",
    "RSS link copied to clipboard" : "RSS saite kopēta starpliktuvē",
    "Could not copy the RSS link, please copy manually:" : "Nevarēja kopēt RSS saiti, lūdzu, kopējiet manuāli:",
    "Activity settings" : "Darbību iestatījumi",
    "Enable RSS feed" : "Ieslēgt RSS plūsmu",
    "RSS feed" : "RSS plūsma",
    "Copy RSS feed link" : "Kopēt RSS plūsmas saiti",
    "Personal notification settings" : "Personisko paziņojumu iestatījumi",
    "Unable to load the activity list" : "Nevarēja ielādēt darbību sarakstu",
    "Choose for which activities you want to get an email or push notification." : "Izvēlieties, par kurām darbībām vēlaties saņemt e-pastu vai paziņojumu.",
    "Choose for which activities you want to get a push notification." : "Izvēlieties, par kurām darbībām vēlaties saņemt paziņojumu.",
    "Notification" : "Paziņojums",
    "Enable notification emails" : "Iespējot paziņojumu e-pastus",
    "Daily activity summary" : "Dienas darbību kopsavilkums",
    "Send daily activity summary in the morning" : "Sūtīt dienas darbību kopsavilkumu no rīta",
    "Default settings" : "Noklusējuma iestatījumi",
    "Unable to save the settings" : "Nevarēja saglabāt iestatījumus",
    "No more events to load" : "Nav vairs notikumu, ko ielādēt"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/lv.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "%s personīgā darbību plūsma ",
    "Your feed URL is invalid" : "Jūsu plūsmas URL nav derīgs.",
    "Activity feed for %1$s" : "%1$s darbību plūsma",
    "Activity feed" : "Darbību plūsma",
    "Your settings have been updated." : "Jūsu uzstādījumi ir atjaunoti.",
    "Settings have been updated." : "Iestādījumi ir atjaunoti.",
    "Recent activity" : "Jaunākās darbības",
    "No activities" : "Nav darbību",
    "More activities" : "Vairāk darbību",
    "_and %n more…_::_and %n more…_" : ["un vēl %n...","un vēl %n...","un vēl %n..."],
    "All activities" : "Visas darbības",
    "By others" : "Citu",
    "By you" : "Jūsu",
    "Activity at %s" : "Darbības %s",
    "Hello %s" : "Sveiki, %s",
    "Hello %s," : "Sveiki, %s,",
    "There was some activity at %s" : "%s bija kaut kādas darbības",
    "_and %n more _::_and %n more _" : ["un vēl %n","un vēl %n","un vēl %n"],
    "Mail" : "E-pasts",
    "Activity" : "Darbības",
    "Notifications" : "Paziņojumi",
    "Send email" : "Nosūtīt e-pasta ziņojumu",
    "Activity notification configuration" : "Darbību paziņojumu konfigurācija",
    "Today" : "Šodien",
    "Yesterday" : "Vakar",
    "You need to set up your email address before you can receive notification emails." : "Lai saņemtu paziņojumus e-pastā, jūsu profilā ir nepieciešams uzstādīt e-pasta adresi.",
    "Send activity emails" : "Sūtīt darbību e-pasta ziņojumus",
    "As soon as possible" : "Pēc iespējas atrāk",
    "Hourly" : "Ik stundu",
    "Daily" : "Katru dienu",
    "Weekly" : "Katru nedēļu",
    "You commented" : "Tu piebildi",
    "Message deleted by author" : "Ziņojumu izdzēsa autors",
    "Open {filename}" : "Atvērt {filename}",
    "in {path}" : "{path}",
    "Home" : "Sākums",
    "Could not load activities" : "Nevarēja ielādēt darbības",
    "Loading activities" : "Ielādē darbības",
    "This stream will show events like additions, changes & shares" : "Šajā plūsmā tiks parādīti papildinājumu, izmaiņu un koplietošanas notikumi",
    "No activity yet" : "Vēl nav darbības",
    "Loading more activities" : "Ielādē vairāk darbību",
    "No more activities." : "Nav vairāk darbību.",
    "Could not enable RSS link" : "Nevarēja iespējot RSS saiti",
    "RSS link copied to clipboard" : "RSS saite kopēta starpliktuvē",
    "Could not copy the RSS link, please copy manually:" : "Nevarēja kopēt RSS saiti, lūdzu, kopējiet manuāli:",
    "Activity settings" : "Darbību iestatījumi",
    "Enable RSS feed" : "Ieslēgt RSS plūsmu",
    "RSS feed" : "RSS plūsma",
    "Copy RSS feed link" : "Kopēt RSS plūsmas saiti",
    "Personal notification settings" : "Personisko paziņojumu iestatījumi",
    "Unable to load the activity list" : "Nevarēja ielādēt darbību sarakstu",
    "Choose for which activities you want to get an email or push notification." : "Izvēlieties, par kurām darbībām vēlaties saņemt e-pastu vai paziņojumu.",
    "Choose for which activities you want to get a push notification." : "Izvēlieties, par kurām darbībām vēlaties saņemt paziņojumu.",
    "Notification" : "Paziņojums",
    "Enable notification emails" : "Iespējot paziņojumu e-pastus",
    "Daily activity summary" : "Dienas darbību kopsavilkums",
    "Send daily activity summary in the morning" : "Sūtīt dienas darbību kopsavilkumu no rīta",
    "Default settings" : "Noklusējuma iestatījumi",
    "Unable to save the settings" : "Nevarēja saglabāt iestatījumus",
    "No more events to load" : "Nav vairs notikumu, ko ielādēt"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
